@@ -4,13 +4,13 @@
 #' and can be considered the smallest granual of location data. If you know what
 #' station you want, you can quickly get all manner of data from it
 #'
-#' @import httr rgeos rgdal sp
-#' @importFrom plyr compact
+#' @export
+#' @import rgeos rgdal sp
+#' 
 #' @template rnoaa
 #' @template rnoaa2
 #' @template stations
 #' @return A list of metadata.
-#' @export
 #' @examples \dontrun{
 #' # Get metadata on all stations
 #' ncdc_stations()
@@ -52,11 +52,10 @@
 
 ncdc_stations <- function(stationid=NULL, datasetid=NULL, datatypeid=NULL, locationid=NULL,
   startdate=NULL, enddate=NULL, sortfield=NULL, sortorder=NULL, limit=25, offset=NULL,
-  datacategoryid=NULL, extent=NULL, radius=10, callopts=list(), token=NULL, dataset=NULL,
-  station=NULL, location=NULL, locationtype=NULL, page=NULL)
+  datacategoryid=NULL, extent=NULL, radius=10, token=NULL, dataset=NULL,
+  station=NULL, location=NULL, locationtype=NULL, page=NULL, ...)
 {
-  if(is.null(token))
-    token <- getOption("noaakey", stop("you need an API key NOAA data"))
+  token <- check_key(token)
 
   if(!is.null(stationid)){
     url <- sprintf('http://www.ncdc.noaa.gov/cdo-web/api/v2/stations/%s', stationid)
@@ -77,8 +76,7 @@ ncdc_stations <- function(stationid=NULL, datasetid=NULL, datatypeid=NULL, locat
                          extent=extent))
   }
 
-  callopts <- c(add_headers("token" = token), callopts)
-  temp <- GET(url, query=args, config=callopts)
+  temp <- GET(url, query=args, add_headers("token" = token), ...)
   tt <- check_response(temp)
   if(is(temp, "character")){
     all <- list(meta=NULL, data=NULL)
