@@ -12,14 +12,14 @@ test_that("ncdc_locs returns the correct class", {
   expect_is(uu, "ncdc_locs")
   expect_is(tt$meta, "list")
   expect_is(tt$data, "data.frame")
-  expect_is(tt$meta$totalCount, "numeric")
+  expect_is(tt$meta$totalCount, "integer")
   expect_is(tt$data$mindate, "character")
 })
 
 test_that("ncdc_locs returns the correct dimensions", {
   expect_equal(length(tt$meta), 3)
   expect_equal(dim(tt$data), c(25,5))
-  expect_equal(dim(uu$data), c(52,5))
+  expect_equal(NCOL(uu$data), 5)
   expect_equal(length(tt), 2)
   expect_equal(length(uu), 2)
 })
